<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests\AlmacenRequest;
use App\Almacen;
use App\Tienda;
use App\Producto;
use App\ProductoAlmacen;
use App\User;

class AlmacenController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = User::where('id', auth()->id())->first();        
        $almacenes = Almacen::where('comercio_id', $user->comercio_id)->get();

        return view('admin.almacenes.index', [
            'almacenes' => $almacenes,
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.almacenes.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(AlmacenRequest $request)
    {
        $user = User::where('id', auth()->id())->first();
        $almacen = Almacen::create($request->validated());

        $almacen->al_refrigerado =  (isset($_POST['al_refrigerado']) == '1' ? '1' : '0'); 
        $almacen->al_valorados = (isset($_POST['al_valorados']) == '1' ? '1' : '0');
        $almacen->comercio_id = $user->comercio_id;

        $almacen->save();

        if($almacen->save()){
            $productos = Producto::where('comercio_id', $user->comercio_id)->get();

            foreach($productos as $producto_almacen){
                $productos_almacenes = new ProductoAlmacen();
                $productos_almacenes->producto_id = $producto_almacen->id;
                $productos_almacenes->almacen_id = $almacen->id;
                $productos_almacenes->stock = 0;
                $productos_almacenes->comercio_id = $producto_almacen->comercio_id;

                $productos_almacenes->save();
            }
        }

        return redirect()->route('admin.almacenes.index')->withStatus(__('Almacen Creado.'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $almacenEdit = Almacen::findOrFail($id);

        return view('admin.almacenes.edit',[
            'almacenEdit'   => $almacenEdit,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(AlmacenRequest $request, Almacen $almacenEdit)
    {
        $almacenEdit->update( $request->validated() );

        $almacenEdit->al_refrigerado =  (isset($_POST['al_refrigerado']) == '1' ? '1' : '0'); 
        $almacenEdit->al_valorados = (isset($_POST['al_valorados']) == '1' ? '1' : '0');

        $almacenEdit->save();

        return redirect()->route('admin.almacenes.index')->withStatus(__('Almacen Actualizado.'));
    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Almacen $almacen)
    {
        $almacen->delete();
        return redirect()->route('admin.almacenes.index')->withStatus(__('Almacen Eliminado.'));
    }
}
