<?php

namespace App\Http\Controllers\Api;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use App\Producto;

class ProductApiController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $producto = Producto::get();

        $data = array(
            'status'    => 'success',
            'code'      => 200,
            'message'   => 'La lista de productos  se mostrado creado correctamente',
            'producto'      => $producto,
        );

        return response()->json($data, $data['code']);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        $validate = Validator::make($request->all(), [
            'categoria_id'      => ['required'],
            'pr_nombre'         => ['required', 'string', 'max:255'],
            'pr_slug'           => ['required'],
            'pr_marca'          => ['required', 'string', 'max:255'],
            'pr_imagen'         => ['image'],
            'pr_unidad'         => ['required'],
            'pr_stock'          => ['required'],
            'pr_precio'         => ['required'],
        ]);

        if ($validate->fails()) { 
            $data = array(
                'status'    => 'error',
                'code'      => 400,
                'message'   => 'El Producto no se pudo crear',
                'errors'    => $validate->errors(),
            );          
        }else{
            $producto = new Producto();

            $producto->categoria_id = $request->categoria_id;
            $producto->pr_nombre = $request->pr_nombre;
            $producto->pr_slug = $request->pr_slug;
            $producto->pr_marca = $request->pr_marca;
            //$producto->pr_imagen = $request->pr_imagen;
            $producto->pr_unidad = $request->pr_unidad;
            $producto->pr_stock = $request->pr_stock;
            $producto->pr_precio = $request->pr_precio;
            $producto->comercio_id = '3';

            if($request->hasFile('pr_imagen')){
                $producto->pr_imagen = $request->file('pr_imagen')->store('public');
            }

            $producto->save();

            $data = array(
                'status'    => 'success',
                'code'      => 200,
                'message'   => 'El producto se ha creado correctamente',
                'producto'      => $producto,
            );
        }

        return response()->json($data, $data['code']);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    public function update($id, Request $request)
    {
        if(!empty($request)){
        
            $validate = Validator::make($request->all(), [
                'categoria_id'      => ['required'],
                'pr_nombre'         => ['required', 'string', 'max:255'],
                'pr_marca'          => ['required', 'string', 'max:255'],
                'pr_slug'           => ['required'],
                'pr_imagen'         => ['image'],
                'pr_unidad'         => ['required'],
                'pr_stock'          => ['required'],
                'pr_precio'         => ['required'],
                
            ]);
            
            if ($validate->fails()) {

                $data = array(
                    'status'    => 'error',
                    'code'      => 400,
                    'message'   => 'El Producto no se pudo actualizar',
                    'errors'    => $validate->errors(),
                );   

            }else{

                $producto = Producto::where('id', $id)->update($request->all());
                
                if($request->hasFile('pr_imagen')){
                    $producto->pr_imagen = $request->file('pr_imagen')->store('public');
                }

                //$producto->save();

                $data = array(
                    'status'    => 'success',
                    'code'      => 200,
                    'message'   => 'El producto fue actualizado correctamente',
                    'producto'      => $producto,
                    
                );
            }
        }else{
            $data = array(
                'status'    => 'error',
                'code'      => 400,
                'message'   => 'No se enviaron datos',
            );
        }

        return response()->json($data, $data['code']);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id, Request $request)
    {
        $producto = Producto::find($id);

        if(!empty($producto)){

            $producto->delete();

            $data = array(
                'status'    => 'success',
                'code'      => 200,
                'message'   => 'El producto fue borrado',
                'producto'      => $producto,
            );
        }else {
            $data = array(
                'status'    => 'error',
                'code'      => 404,
                'message'   => 'El producto no se encuentra',
            );
        }

        return response()->json($data, $data['code']);

    }
}
