<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Auth;
use Socialite;
use App\User;
use App\Role;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = '/';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    protected function authenticated($request, $user)
    {
        if (Auth::user()->hasRole('admin')) {
            return redirect('/super-admin');
        } else if (Auth::user()->hasRole('comercio')) {
            return redirect('/comercio');
        }   else if (Auth::user()->hasRole('user')) {
            return redirect('/welcome');
        }
    }

    public function facebook(){
        return Socialite::driver('facebook')->redirect();
    }

    public function facebookRedirect(Request $request){
        
        if (!$request->has('code') || $request->has('denied')) {
            return redirect('/login');
        }

        $socialUser = Socialite::driver('facebook')->user();
        //dd($socialUser);
        
        $user_exist = User::where('email', $socialUser->email)->first();

        if($user_exist){

            Auth::Login($user_exist,true);

            if (Auth::user()->hasRole('admin')) {
                return redirect('/super-admin');
            } else if (Auth::user()->hasRole('comercio')) {
                return redirect('/comercio');
            }   else if (Auth::user()->hasRole('user')) {
                return redirect('/welcome');
            }
        }

        $user = User::firstOrNew(['email' => $socialUser->email]);
        $user->cl_nombre = $socialUser->name;
        $user->cl_documento = 99999999;
        $user->cl_celular = 0;
        $user->status = true;
        $user->password = Hash::make($socialUser->id);
        $user->save();

        $user
            ->roles()
            ->attach(Role::where('name', 'user')->first());
        
        Auth::Login($user,true);

        return redirect('/welcome');
    }

    public function google(){
        return Socialite::driver('google')->redirect();
    }

    public function googleRedirect(Request $request){
        
        if (!$request->has('code') || $request->has('denied')) {
            return redirect('/login');
        }

        $socialUser = Socialite::driver('google')->user();
        
        $user_exist = User::where('email', $socialUser->email)->first();

        if($user_exist){

            Auth::Login($user_exist,true);

            if (Auth::user()->hasRole('admin')) {
                return redirect('/super-admin');
            } else if (Auth::user()->hasRole('comercio')) {
                return redirect('/comercio');
            }   else if (Auth::user()->hasRole('user')) {
                return redirect('/welcome');
            }
        }

        $user = User::firstOrNew(['email' => $socialUser->email]);
        $user->cl_nombre = $socialUser->name;
        $user->cl_documento = 99999999;
        $user->cl_celular = 0;
        $user->status = true;
        $user->password = Hash::make($socialUser->id);
        $user->save();

        $user
            ->roles()
            ->attach(Role::where('name', 'user')->first());
        
        Auth::Login($user,true);

        return redirect('/welcome');
    }
}
