<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Categoria;
use App\Tienda;
use App\User;
use App\Http\Requests\CategoriaRequest;
use Cviebrock\EloquentSluggable\Services\SlugService;

class CategoriaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = User::where('id', auth()->id())->first();
        $categorias = Categoria::where('comercio_id', $user->comercio_id)->get();

        return view('admin.categorias.index',[
            'categorias'    => $categorias,
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.categorias.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $user = User::where('id', auth()->id())->first();
        $request->validate([
            'ct_nombre'    => 'required',
        ]);

        $categorias = [
            'ct_slug' => SlugService::createSlug(Categoria::class, 'ct_slug', $request->ct_nombre),
            'ct_nombre' => $request->ct_nombre,
        ];

        $categoria = Categoria::create($categorias);
        $categoria->comercio_id =  $user->comercio_id;

        $categoria->save();

        return redirect()->route('admin.categorias.index')->withStatus(__('Categoría del Producto Creado.'));

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $categoriaEdit = Categoria::findOrFail($id);

        return view('admin.categorias.edit', [
            'categoriaEdit' => $categoriaEdit,
        ]);

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Categoria $categoriaEdit, CategoriaRequest $request)
    {
        $categoriaEdit->update( $request->validated() );

        return redirect()->route('admin.categorias.index')->withStatus(__('Categoría del Producto Actualizado.'));
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Categoria $categoria)
    {
        $categoria->delete();
        return redirect()->route('admin.categorias.index')->withStatus(__('Categoría Eliminada.'));

    }
}
