<?php

namespace App\Http\Controllers\Cliente;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use App\Direccion;
use App\Http\Requests\DireccionRequest;

class AddressController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = Auth::user()->id;
        $direccion = Direccion::query();

        $records = $direccion->with('users')
                               ->where('user_id', $user);

        $direcciones = collect($records->get());

        return view('cliente.direcciones.index', [
            'records' => $direcciones,
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('cliente.direcciones.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(DireccionRequest $request)
    {
        Direccion::create($request->validated());

        return redirect()->route('cliente.direcciones.index')->withStatus(__('Dirección de envio correctamente'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $direccionEdit = Direccion::findOrFail($id);

        return view('cliente.direcciones.edit', [
            'direccionEdit' => $direccionEdit,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Direccion $direccionEdit, DireccionRequest $request)
    {
        $direccionEdit->update( $request->validated() );

        return redirect()->route('cliente.direcciones.index')->withStatus(__('Dirección actualizada.'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Direccion $direccion)
    {
        $direccion->delete();
        return redirect()->route('cliente.direcciones.index')->withStatus(__('Dirección eliminada.'));
    }
}
