<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\User;
use App\Role;

class ClienteController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $usuarios = User::with('roles')->get();
        $clientes = $usuarios->filter(function ($user, $key) {
            return $user->hasRole('user');
        });

        return view('admin.clientes.index',[
            'clientes' => $clientes,
        ]);
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.clientes.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {   
        $validate = Validator::make($request->all(), [ 
            'cl_nombre' => ['required', 'string', 'max:255'],
            'cl_documento' => ['required', 'string', 'max:255'],
            'cl_celular' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:6', 'confirmed'],
        ]);

        if ($validate->fails()) {
            return back()->withErrors($validate)->withInput();
        }else{

            $user = User::create([
                'cl_nombre' => $request['cl_nombre'],
                'cl_documento' => $request['cl_documento'],
                'cl_celular' => $request['cl_celular'],
                'email' => $request['email'],
                'password' => Hash::make($request['password']),
            ]);

            $user
                ->roles()
                ->attach(Role::where('name', 'user')->first());
        }
        
        return redirect()->route('admin.clientes.index')->withStatus(__('Cliente Creado.'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
