<?php

namespace App\Http\Controllers\Comercio;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\DB;
use App\User;
use App\Role;
use App\Tienda;
use App\Almacen;
use App\Comercio;
use App\Configuracion;
use Auth;
use Illuminate\Support\Facades\Mail;
use App\Jobs\SendComercioCreacionJob;

class ComercioController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('comercio.auth.register');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $validate = Validator::make($request->all(), [ 
            'cl_nombre' => ['required', 'string', 'max:255'],
            'cl_documento' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:6', 'confirmed'],
        ]);

        if ($validate->fails()) {

            return back()->withErrors($validate)->withInput();

        }else{

            DB::beginTransaction();

            try{

                $user = User::create([
                    'cl_nombre' => $request['cl_nombre'],
                    'cl_documento' => $request['cl_documento'],
                    'cl_celular' => 0,
                    'email' => $request['email'],
                    'password' => Hash::make($request['password']),
                    'status' => false,
                ]);

                $user
                    ->roles()
                    ->attach(Role::where('name', 'comercio')->first());

                if($user->exists()){
                    //Crear Comercio
                    $comercio = new Comercio();
                    $comercio->numero = $user->cl_documento;
                    $comercio->nombre = $user->cl_nombre;
                    $comercio->email_contacto = $user->email;
                    $comercio->status = 2;
                    $comercio->logo = null;
                    $comercio->save();

                    //Agregar el comercio al usuario
                    $user_comercio = User::firstOrNew(['id' => $user->id]);
                    $user_comercio->comercio_id = $comercio->id;
                    $user_comercio->save();

                }

                $tienda = new Tienda();
                $tienda->tn_nombre = $user->cl_nombre;
                $tienda->comercio_id = $comercio->id;
                $tienda->tn_pais = "PERÚ";
                $tienda->tn_ciudad = "Ciudad";
                $tienda->tn_direccion = "Dirección";
                $tienda->tn_latitud = "-9.189967";
                $tienda->tn_longitud = "-75.015152";
                $tienda->save();
    
                if($tienda->save()){
                    $almacen = new Almacen();
                    $almacen->comercio_id = $tienda->comercio_id;
                    $almacen->al_nombre = "Almacén Principal";
                    $almacen->al_codigo = "000000";
                    $almacen->al_direccion = "Dirección";
                    $almacen->al_departamento = "Departamento";
                    $almacen->al_provincia = "Provincia";
                    $almacen->al_distrito = "Distrito";
                    $almacen->al_pais = "PERÚ";
                    $almacen->al_codpostal = "051";
                    $almacen->al_refrigerado = 0;
                    $almacen->al_valorados = 0;
                    $almacen->al_telefono1 = "999999999";
                    $almacen->al_email1 = $user->email;
                    $almacen->al_latitud = "-9.189967";
                    $almacen->al_longitud = "-75.015152";
    
                    $almacen->save();
                    
                    if($almacen->exists()){
                        $configuraciones = new Configuracion;
                        $configuraciones->comercio_id = $almacen->comercio_id;
                        $configuraciones->almacen_id = $almacen->id;
                        $configuraciones->save();
                    }
                }

                //Envio de Email creación de Comercio
                dispatch(new SendComercioCreacionJob($user, $comercio));

                Auth::login($user, true);

                DB::commit();

            }catch (\Exception $e){

                DB::rollBack();

                return redirect()->back()->withStatus(__('Error al crear el comercio'));
            }
            
        }
        
        return redirect('/comercio')->withStatus(__('El Comercio fue creado correctamente.'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
