<?php

namespace App\Http\Controllers\Comercio;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Movimientos;
use App\Almacen;
use App\ProductoAlmacen;
use App\Producto;
use App\MovimientoProducto;
use App\Http\Resources\MovimientoCollection;
use Illuminate\Support\Facades\DB;
use App\User;

class MovimientosController extends Controller
{
    public function index(){
        return view('admin.movimientos.index');
    }

    public function records(){

        $user = User::where('id', auth()->id())->first();
        $records = Movimientos::where('comercio_id', $user->comercio_id)->orderBy('created_at','desc')->get();
        
        return new MovimientoCollection($records);
    }

    public function tables(){

        $user = User::where('id', auth()->id())->first();
        $almacenes = Almacen::where('comercio_id',$user->comercio_id)->get();
        $items = ProductoAlmacen::with(['almacen', 'producto'])->where('comercio_id',$user->comercio_id)->get();

        return compact('almacenes', 'items');
    }

    public function items(Request $request){

        $user = User::where('id', auth()->id())->first();
        $records = Producto::with('producto_almacen')->where('comercio_id',$user->comercio_id)
                        ->Search($request->input('search'))->Limited($request->input('limited'))->get();

        return collect($records)->transform(function($row) {
            return  [
                'id' => $row->id,
                'producto_almacen' => $row->producto_almacen,
                'description' => $row->pr_nombre,
                'full_description_search' => $row->pr_nombre
            ];
        });
    }

    public function store(Request $request){

        $user = User::where('id', auth()->id())->first();
        $movimiento = new Movimientos();
        $movimiento->almacen_inicial = $request->almacen_inicial;
        $movimiento->almacen_destino = $request->almacen_destino;
        $movimiento->motivo = $request->motivo;
        $movimiento->state_type_id = 4;
        $movimiento->comercio_id = $user->comercio_id;
        
        $movimiento->save();

        //Guardar stock movimientos productos - almacen 
        if($movimiento->save()){

            foreach ($request->items as $item){
                
                $movimiento_stock = new MovimientoProducto();
                $movimiento_stock->producto_id = $item['producto_id'];
                $movimiento_stock->movimiento_id = $movimiento->id;
                $movimiento_stock->stock = $item['quantity'];

                $movimiento_stock->save();
            }

        }
        //Falta
        return [
            'success' => true,
            'message' => 'Movimiento generedo.',
        ];
    }

    public function view($id){

        $movimiento = Movimientos::with(['almacenInicial', 'almacenDestino'])->findOrFail($id);
        $movimiento_stock = MovimientoProducto::with('producto')->where('movimiento_id', $id)->get();

        return view('admin.movimientos.view', [
            'movimiento' => $movimiento,
            'movimiento_stock' => $movimiento_stock,
        ]);
    }

    public function accept($id){

        $movimiento = Movimientos::findOrFail($id);
        $movimiento_stock = MovimientoProducto::with('producto')->where('movimiento_id', $id)->get();
        $producto_almacen_inicial = ProductoAlmacen::where('almacen_id', $movimiento->almacen_inicial)->get();
        $producto_almacen_destino = ProductoAlmacen::where('almacen_id', $movimiento->almacen_destino)->get();
        
        DB::beginTransaction();

            try {
                foreach ($producto_almacen_inicial as $item){

                    foreach($movimiento_stock as $row){

                        $producto_almacen = ProductoAlmacen::firstOrNew(['id' => $item->id]);

                        if( $item->producto_id == $row->producto_id){
                            $producto_almacen->stock = $producto_almacen->stock - $row->stock;
                            $producto_almacen->save();
                        }
                    }
                }

                foreach ($producto_almacen_destino as $item){

                    foreach($movimiento_stock as $row){

                        $producto_almacen = ProductoAlmacen::firstOrNew(['id' => $item->id]);

                        if( $item->producto_id == $row->producto_id){
                            $producto_almacen->stock = $producto_almacen->stock + $row->stock;
                            $producto_almacen->save();
                        }
                    }
                }

                $movimiento->update([
                    'state_type_id' => 1,
                ]);
                
                DB::commit();
            }
            catch (Exception $e) {
                DB::rollBack();

                return [
                    'success' => false,
                    'message' => $e->getMessage()
                ];
            }
            
        return [
            'success' => true,
            'message' => 'Movimiento realizado exitosamente'
        ];


        /* DB::beginTransaction();
        $res['success'] = true;
        DB::commit();
        DB::rollback(); */
    }

    public function deny($id){

        $movimiento = Movimientos::findOrFail($id);

        $movimiento->update([
            'state_type_id' => 2,
        ]);
        
        return [
            'success' => true,
            'message' => 'Movimiento Rechazado.',
        ];
    }
}
