<?php

namespace App\Http\Controllers\Culqi;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Culqi\Culqi;
use Culqi\CulqiException;
use App\Order;
use App\Producto;
use App\Transactions;
use Carbon\Carbon;
use App\OrdenDetalle;
use App\User;
use App\Role;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use App\Mail\OrdenUsuarioRegistrado;
use App\Jobs\SendEmailOrdenUsuario;
use App\Jobs\SendOrdenCreacionJob;
use App\Jobs\SendOrdenCreacionProductoJob;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\DB;
use App\Configuracion;
use App\ProductoAlmacen;
//use RealRashid\SweetAlert\Facades\Alert;

class OrderController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    protected $hashKey;

    protected $expires;

    public $transaction_id;

    public function index(){

        $user = User::where('id', auth()->id())->first();
        $ordenes = Order::where('comercio_id', $user->comercio_id)->orderBy('created_at', 'DESC')->get();

        return view('admin.orden.index', [
            'ordenes'   => $ordenes,
        ]);
    }

    public function pagar(Request $request){
        
        $token = $request->input('token');
        $email = $request->input('email');
        $total = $request->input('monto');
        $descripcion = $request->input('descripcion');
        $productos = $request->get('productos');
        $producto = $request->get('producto');

        if($producto){
            $producto = Producto::findOrFail($producto);
        }

        if($token){
            //sk_test_9pIAVmMhBqd9xly7
            $SECRET_KEY = "sk_test_9pIAVmMhBqd9xly7";
            $culqi = new Culqi(array('api_key' => $SECRET_KEY));

            try{

                $charge = $culqi->Charges->create(
                    array(
                      "amount" => $total*100,
                      "capture" => true,
                      "currency_code" => "PEN",
                      "description" => $descripcion,
                      "installments" => 0,
                      "email" => $email,
                      "antifraud_details" => array(
                            "address" => "Av. Lima 123",
                            "address_city" => "LIMA",
                            "country_code" => "PE",
                            "first_name" => "Will",
                            "last_name" => "Muro",
                            "phone_number" => "9889678986",
                        ),
                      "source_id" => $token
                    )
                );

                if($charge->object == "charge"){

                    if(User::where('email',$email)->exists()){
                        DB::beginTransaction();
                        try {

                            $this->crearTransaccion($charge, $producto, $productos);

                            DB::commit();
                        }catch (Exception $e) {
                            DB::rollBack();
            
                            return [
                                'success' => false,
                                'message' => $e->getMessage()
                            ];
                        }
                    }else{
                        DB::beginTransaction();
                        try {

                            $this->RegistroPagoRapido($email);
                            $this->crearTransaccion($charge, $producto, $productos);

                            DB::commit();
                        }catch (Exception $e) {
                            DB::rollBack();
            
                            return [
                                'success' => false,
                                'message' => $e->getMessage()
                            ];
                        }
                    }

                }elseif($charge->object == "error"){

                    $params_array = json_decode(json_encode($charge), true);

                    $transaction = new Transactions();

                    $transaction->amount = $total*100;
                    $transaction->installments = 0;
                    $transaction->currency = "PEN";
                    $transaction->email = $email;
                    $transaction->description = $descripcion;

                    $transaction->object_status = $params_array['object'];
                    $transaction->id_transaction = $params_array['charge_id'];
                    $transaction->outcome_type = $params_array['type'];
                    $transaction->outcome_code = $params_array['code'];
                    $transaction->outcome_merchant_message = $params_array['merchant_message'];
                    $transaction->outcome_user_message = $params_array['user_message'];

                    /*-------Details-------*/

                    $transaction->first_name = "Will";
                    $transaction->last_name = "Muro";
                    $transaction->address = "Av. Lima 123";
                    $transaction->address_city = "LIMA";
                    $transaction->country_code = "PE";
                    $transaction->phone = "9889678986";

                    //Comercio
                    if($producto){
                        $transaction->comercio_id = $producto->comercio_id;
                    }
                    if($productos){
                        $transaction->comercio_id = $productos[0]->comercio_id;
                    }

                    $transaction->save();

                }

                return json_encode($charge);

            }catch(Exception $e){

                return json_encode($e->getMessage());

            }
        
        }

    }
    
    /* ------------- Crear Transacción -------------- */

    public function crearTransaccion($charge, $producto, $productos){

        $params_array = json_decode(json_encode($charge), true);
        $params_array_source = json_decode(json_encode($charge->source), true);
        $params_iin = json_decode(json_encode($charge->source->iin), true);
        $params_iin_issuser = json_decode(json_encode($charge->source->iin->issuer), true);
        $params_client = json_decode(json_encode($charge->source->client), true);
        $params_message = json_decode(json_encode($charge->outcome), true);
        $params_antifraud = json_decode(json_encode($charge->antifraud_details), true);
        $params_fee = json_decode(json_encode($charge->fee_details->variable_fee), true);

        //var_dump($params_array_source);

        $transaction = new Transactions();
        $transaction->object_status = $params_array['object'];
        $transaction->id_transaction = $params_array['id'];
        $transaction->creation_date = date("Y-m-d H:i:s", ($params_array['creation_date'])/1000);
        $transaction->amount = $params_array['amount'];
        $transaction->current_amount = $params_array['current_amount'];
        $transaction->installments = $params_array['installments'];
        $transaction->installments_amount = $params_array['installments_amount'];
        $transaction->currency = $params_array['currency_code'];
        $transaction->email = $params_array['email'];
        $transaction->description = $params_array['description'];
        
        /* --------Bank--------*/
        
        $transaction->type = $params_array_source['type'];
        $transaction->card_number = $params_array_source['card_number'];
        $transaction->last_four = $params_array_source['last_four'];
        $transaction->bin = $params_iin['bin'];
        $transaction->card_brand = $params_iin['card_brand'];
        $transaction->card_type = $params_iin['card_type'];
        $transaction->card_category = $params_iin['card_category'];
        $transaction->bank_name = $params_iin_issuser['name'];
        $transaction->bank_country = $params_iin_issuser['country'];
        $transaction->bank_website = $params_iin_issuser['website'];
        $transaction->bank_phone = $params_iin_issuser['phone_number'];

        /*-------Client--------*/

        $transaction->ip = $params_client['ip'];
        $transaction->ip_country = $params_client['ip_country'];
        $transaction->ip_country_code = $params_client['ip_country_code'];
        $transaction->browser = $params_client['browser'];
        $transaction->device_fingerprint = $params_client['device_fingerprint'];
        $transaction->device_type = $params_client['device_type'];

        /*-------Message-------*/

        $transaction->outcome_type = $params_message['type'];
        $transaction->outcome_code = $params_message['code'];
        $transaction->outcome_merchant_message = $params_message['merchant_message'];
        $transaction->outcome_user_message = $params_message['user_message'];

        /*---------------------*/

        $transaction->fraud_score = $params_array['fraud_score'];
        $transaction->transfer_amount = $params_array['transfer_amount'];
        $transaction->total_fee_taxes = $params_array['total_fee_taxes'];

        /*-------Details-------*/

        $transaction->first_name = $params_antifraud['first_name'];
        $transaction->last_name = $params_antifraud['last_name'];
        $transaction->address = $params_antifraud['address'];
        $transaction->address_city = $params_antifraud['address_city'];
        $transaction->country_code = $params_antifraud['country_code'];
        $transaction->phone = $params_antifraud['phone'];
        $transaction->object_type = $params_antifraud['object'];

        /*------Commision-----*/

        $transaction->commision_total = $params_fee['total'];

        if($producto != null){
            $transaction->comercio_id = $producto->comercio_id;
        }
        if($productos){
            $transaction->comercio_id = $productos[0]['comercio_id'];
        }
        
        $transaction->save();

        $data = array(
            'status'        => 'success',
            'code'          => 200,
            'message'       => 'Transacción realizada correctamente', 
        );

    }

    /* ------------ Fin de Crear Transacción -------- */


    public function createOrden(Request $request)
    {
        $productos = $request->get('productos');
        //$producto = $request->get('producto');
        $transaction_id = $request->input('transaction_id');
        $fraud_score = $request->input('fraud_score');
        $total = $request->input('total');
        $num_orden = $request->input('num_orden');
        $email = $request->input('email');

        $now = Carbon::now();

        $orden = new Order;
        if(Auth::check()){
            $orden->user_id = Auth::user()->id;
        }else{
            $usuario = User::where('email', $email)->first();
            $orden->user_id = $usuario->id;
        }
        $orden->transaction_id = $transaction_id;
        $orden->num_orden = $num_orden;
        $orden->total = $total / 100;

        if($fraud_score >= 15){
            $orden->revision_manual = true;
            $orden->status = 'Detenida';
        }else{
            $orden->status = 'Pendiente';
            $orden->revision_manual = false;
        }
        $orden->fecha_creacion = $now->format('Y-m-d H:i');
        $orden->fecha_limite = $now->format('Y-m-d H:i');
        $orden->fecha_entrega = $now->addDay(5)->format('Y-m-d H:i');
        $orden->comercio_id = $productos[0]['comercio_id'];

        $orden->save();

        foreach($productos as $producto){

            $id = intval($producto['id']);
            $cantidad = intval($producto['cantidad']);
            $precio = floatval($producto['precio'])* floatval($producto['cantidad']);
            
            $this->saveOrderDetail($id, $cantidad, $precio, $orden->id);
            $this->decreaseQuantities($id, $cantidad);
        }

        dispatch(new SendOrdenCreacionJob($orden, $productos));

        return $orden;
    }


    protected function decreaseQuantities($id , $cantidad)
    {
        $product = Producto::findOrFail(intval($id));

        $configuracion = Configuracion::where('comercio_id', $product->comercio_id)->first();

        if($configuracion->almacen_id){
            $producto_almacen = ProductoAlmacen::where('almacen_id', $configuracion->almacen_id)->first();
            $producto_almacen->update(['stock' => $producto_almacen->stock - intval($cantidad)]);
        }

        //$product->update(['pr_stock' => $product->pr_stock - intval($cantidad)]);
    }

    /* Estados del pedido */

    //Cancelado
    public function ordenCancelada(Request $request)
    {
        $orden = Order::find($request->id);
        $orden->status = 'Cancelado';
        $orden->save();

        $this->getOrdenProducto($request->id);
  
        return response()->json(['success'=>'Orden Cancelada']);
    }

    //Entregado
    public function ordenEntregado(Request $request)
    {
        $orden = Order::find($request->id);
        $orden->status = 'Entregado';
        $orden->save();
  
        return response()->json(['success'=>'Orden Entregada']);
    }

    //Verificado
    public function ordenVerificado(Request $request)
    {
        $orden = Order::find($request->id);
        $orden->status = 'Verificado';
        $orden->revision_manual = false;
        $orden->save();
  
        return response()->json(['success'=>'Orden Verificado']);
    }

    public function ordenEstado(Request $request)
    {
        $orden = Order::find($request->id);
        if( $request->estado == 'Aceptada'){
            $orden->status = $request->estado;
        }elseif( $request->estado == 'Demorado' ){
            $orden->status = $request->estado;
        }elseif( $request->estado == 'Reembolsado' ){

            $this->Reembolso($orden->id);

            $orden->status = $request->estado;
        }
    
        $orden->save();
  
        return response()->json(['success'=>'Orden Aceptada']);
    }

    /* Fin de los estados */

    protected function getOrdenProducto($id){
        $orderDetail = OrdenDetalle::where('orden_id', $id)->get();

        foreach($orderDetail as $productoItem){
            $this->incrementQuantities($productoItem->producto_id, $productoItem->cantidad);
        }

    }

    protected function incrementQuantities($id, $cantidad)
    {
        $product = Producto::findOrFail($id);

        $configuracion = Configuracion::where('comercio_id', $product->comercio_id)->first();

        if($configuracion->almacen_id){
            $producto_almacen = ProductoAlmacen::where('almacen_id', $configuracion->almacen_id)->first();
            $producto_almacen->update(['stock' => $producto_almacen->stock - intval($cantidad)]);
        }

        //$product->update(['pr_stock' => $product->pr_stock + $cantidad]);
    }

    protected function saveOrderDetail($id, $cantidad, $precio, $order_id){

        OrdenDetalle::create([
            'orden_id'      => $order_id,
            'producto_id'   => $id,
            'cantidad'      => $cantidad,
            'precio'        => $precio,
        ]);
    }


    public function viewOrder($codigo){

        $orden = Order::findOrFail($codigo);
        $detalle = OrdenDetalle::where('orden_id', $orden->id)->get();


        return view('admin.orden.detalle', [
            'orden'     => $orden,
            'detalle'   => $detalle,
        ]);
    }

    /* ------------- Aceptar la Disputa para el Reembolso -------------- */

    public function Reembolso($id){

        $orden = Order::find($id);

        $SECRET_KEY = "sk_test_9pIAVmMhBqd9xly7";
        $culqi = new Culqi(array('api_key' => $SECRET_KEY));

        try{

            $devolucion = $culqi->Refunds->create(
                array(
                    "amount" => $orden->total * 100,
                    "charge_id" => $orden->transaction_id,
                    "reason" => "solicitud_comprador"
                )
            );

            return json_encode($devolucion);

        }catch(Exception $e){

            return json_encode($e->getMessage());

        }
        
    }

    /* --------------- Registro de Pago Rápido ---------------- */

    public function RegistroPagoRapido($email) {

        //Generando Password aleatorio
        $pwd = str_random(12);

        $token = $this->createNewToken();

        $user = User::create([
            'cl_nombre' => 'Usuario',
            'cl_documento' => '00000000',
            'cl_celular' => '+51 000 000 000',
            'email' => $email,
            'password' => Hash::make($pwd),
            'token' => $token,
            'status' => true,
        ]);

        $user
            ->roles()
            ->attach(Role::where('name', 'user')->first());

        //Envio de Email
        
        dispatch(new SendEmailOrdenUsuario($email, $pwd, $token));

    }

    public function createOrdenRapido(Request $request)
    {
        $producto = Producto::findOrFail($request->get('producto'));
        $transaction_id = $request->input('transaction_id');
        $fraud_score = $request->input('fraud_score');
        $total = $request->input('total');
        $num_orden = $request->input('num_orden');
        $email = $request->input('email');

        $now = Carbon::now();

        $orden = new Order;
        if(Auth::check()){
            $orden->user_id = Auth::user()->id;
        }else{
            $usuario = User::where('email', $email)->first();
            $orden->user_id = $usuario->id;
        }
        $orden->transaction_id = $transaction_id;
        $orden->num_orden = $num_orden;
        $orden->total = $total / 100;

        if($fraud_score >= 15){
            $orden->revision_manual = true;
            $orden->status = 'Detenida';
        }else{
            $orden->status = 'Pendiente';
            $orden->revision_manual = false;
        }
        $orden->fecha_creacion = $now->format('Y-m-d H:i');
        $orden->fecha_limite = $now->format('Y-m-d H:i');
        $orden->fecha_entrega = $now->addDay(5)->format('Y-m-d H:i');
        $orden->comercio_id = $producto->comercio_id;

        $orden->save();
        
        $id = $producto->id;
        $cantidad = $request->input('cantidad');
        $precio = $total / 100;

        $this->saveOrderDetail($id, $cantidad, $precio, $orden->id);
        $this->decreaseQuantities($id, $cantidad);

        dispatch(new SendOrdenCreacionProductoJob($orden, $producto, $cantidad));
        
        return $orden;
    }

    public function createNewToken()
    {
        return hash_hmac('sha256', Str::random(40), env('APP_KEY'));
    }

}
