<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Producto;
use App\Categoria;
use App\Http\Requests\ProductoRequest;
use App\Almacen;
use App\Tienda;
use App\ProductoAlmacen;
use App\ProductoImagen;
use App\User;
use Cviebrock\EloquentSluggable\Services\SlugService;

class ProductoController extends Controller
{
    public function index()
    {
        $user = User::where('id', auth()->id())->first();
        $producto = Producto::where('comercio_id', $user->comercio_id)->get();
        
        return view('admin.productos.index',[
            'producto'  => $producto,
        ]);
    }

    public function record($id)
    {
        $record = Producto::findOrFail($id);

        return $record;
    }

    public function tables(){

        $user = User::where('id', auth()->id())->first();
        $almacenes = Almacen::where('comercio_id',$user->comercio_id)->get();
       
        return compact('almacenes');

    }
    public function item_tables($producto_id)
    {
        $producto_almacenes = ProductoAlmacen::where('producto_id',$producto_id)->get();
        $items = array();
         
        foreach($producto_almacenes as $producto_almacen){
            $items[] = [
                'id' => $producto_almacen->id,
                'producto_id' => $producto_almacen->producto_id,
                'almacen_id' => $producto_almacen->almacen_id,
                'stock' => $producto_almacen->stock
            ];
        }
        return compact('items');
    }
    
    public function create()
    {
        $user = User::where('id', auth()->id())->first();
        $categoriaShow = Categoria::where('comercio_id', $user->comercio_id)->get();
        return view('admin.productos.create',[
            'categoriaShow'     => $categoriaShow,
        ]);

    }

    public function store(ProductoRequest $request)
    {
        $user = User::where('id', auth()->id())->first();
        
        try{
            $producto = new Producto;
            $producto->categoria_id = $request->categoria_id;
            $producto->pr_nombre = $request->pr_nombre;
            $producto->pr_slug = SlugService::createSlug(Producto::class, 'pr_slug', $request->pr_nombre);
            $producto->pr_marca = $request->pr_marca;
            $producto->pr_unidad = $request->pr_unidad;
            $producto->pr_stock = $request->pr_stock;
            $producto->pr_precio = $request->pr_precio; 

            if($request->hasFile('pr_imagen')){
                $producto->pr_imagen = $request->file('pr_imagen')->store('public');
            }
            $producto->comercio_id = $user->comercio_id;

            $producto->save();

            $almacenes = Almacen::where('comercio_id', $producto->comercio_id )->get();

            foreach($almacenes as $almacen){

                $producto_almacen = new ProductoAlmacen();
                $producto_almacen->producto_id = $producto->id;
                $producto_almacen->almacen_id = $almacen->id;
                $producto_almacen->stock = 0;
                $producto_almacen->comercio_id = $almacen->comercio_id;
                $producto_almacen->save();
            }
        }
        catch(\Exception $e){
            return back()->withStatus(__('Recuerde incluir una imagen de su producto.'));
        }
        
        return redirect()->route('admin.productos.index')->withStatus(__('Producto Creado.'));
    }

    public function store_stock(Request $request){

        if($request->items){
            foreach( $request->items as $add_stock){
                $id = $add_stock['id'];
                $producto_almacen = ProductoAlmacen::firstOrNew(['id' => $id]);
                $producto_almacen->stock = $add_stock['stock'];
                $producto_almacen->save();
            }
        }

        return [
            'success' => true,
            'message' => 'Stock del producto editado con éxito',
        ];

    }

    public function show()
    {
        $categorias = Categoria::with('getCategoriaProducto')->get();

        return response()->json($categorias);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $productoEdit = Producto::findOrFail($id);
        $categoriaShow = Categoria::all();

        $categoriesForProduct = $productoEdit->CategoriasProducto()->get();

        return view('admin.productos.edit', [
            'productoEdit' => $productoEdit,
            'categoriaShow'     => $categoriaShow,
            'categoriesForProduct' => $categoriesForProduct,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Producto $productoEdit, ProductoRequest $request)
    {
        $productoEdit->update( $request->validated() );

        if($request->hasFile('pr_imagen')){
            $productoEdit->pr_imagen = $request->file('pr_imagen')->store('public');
        }
        
        $productoEdit->save();

        return redirect()->route('admin.productos.index')->withStatus(__('Producto Actualizado.'));
    }

    public function upload(Request $request){
        $producto_id = $request->input('producto_id');
        $upload = $request->file('file');

        if ($upload) {
    
            $productImage = new ProductoImagen([
                'path'=> $upload->store('public'),
                'producto_id'   => $producto_id,
            ]);
    
            $productImage->save();
        }

        return response()->json(['success'=>'Se subio correctamente']);
    }

    public function image_delete($id){
        $image = ProductoImagen::findOrFail($id);

        $image->delete();

        return redirect()->back()->withStatus(__('Imagen eliminada de la Galería.'));
    }

    public function destroy(Producto $producto)
    {
        $producto->delete();
        return redirect()->route('admin.productos.index')->withStatus(__('Producto Eliminado.'));

    }
}
