<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Http\Requests\TiendaRequest;
use App\Tienda;
use App\User;

class TiendaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $user = User::where('id', auth()->id())->first();
        $tiendas = Tienda::where('comercio_id', $user->comercio_id)->get();

        return view('admin.tiendas.index',[
            'tiendas'   => $tiendas,
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.tiendas.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(TiendaRequest $request)
    {
        $user = User::where('id', auth()->id())->first();
        $tienda = Tienda::create($request->validated());

        if($request->hasFile('tn_imagen')){
            $tienda->tn_imagen = $request->file('tn_imagen')->store('public');
        }

        $tienda->comercio_id = $user->comercio_id;

        $tienda->save();

        return redirect()->route('admin.tiendas.index')->withStatus(__('Tienda Creada.'));
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $tiendaEdit = Tienda::findOrFail($id);

        return view('admin.tiendas.edit',[
            'tiendaEdit'   => $tiendaEdit,
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(TiendaRequest $request, Tienda $tiendaEdit)
    {
        $tiendaEdit->update( $request->validated() );

        if($request->hasFile('tn_imagen')){
            $tiendaEdit->tn_imagen = $request->file('tn_imagen')->store('public');
        }
        
        $tiendaEdit->save();

        return redirect()->route('admin.tiendas.index')->withStatus(__('Tienda Actualizada.'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
