<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Cviebrock\EloquentSluggable\Sluggable;

class Producto extends Model
{
    use Sluggable;

    protected $with = ['comercio'];

    protected $table = 'productos';

    protected $fillable = [
        'categoria_id', 'pr_nombre', 'pr_slug', 'pr_marca', 'pr_imagen', 'pr_unidad', 'pr_stock', 'pr_precio', 'comercio_id',
    ];

    public function CategoriasProducto(){ 
        return $this->belongsTo('App\Categoria', 'categoria_id');
    }

    public function scopeMightAlsoLike($query)
    {
        return $query->inRandomOrder()->take(4);
    }

    public function ordenDetalle()
	{
		return $this->hasOne('App\OrdenDetalle');
    }
    
    public function comercio()
	{
		return $this->belongsTo('App\Comercio', 'comercio_id');
    }

    public function producto_almacen()
	{
		return $this->hasMany('App\ProductoAlmacen');
    }

    public function producto_imagen()
	{
		return $this->hasMany('App\ProductoImagen');
    }
    
    public function scopeSearch($query,$search)
    {
        if($search){
            $query->whereRaw('CONCAT( IF(ISNULL(id),"",id)," ", pr_nombre) LIKE "%'.$search.'%"');
        }
    }

    public function scopeLimited($query,$limited)
    {
        if($limited){
            $query->limit($limited);
        }
    }

    public function sluggable()
    {
        return [
            'pr_slug' => [
                'source' => 'pr_nombre',
            ]
        ];
    }
}
