@extends('layouts.master')

@section('css')
<!-- DataTables -->
<link href="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- Responsive datatable examples -->
<link href="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('breadcrumb')
<h3 class="page-title">{{ __('Historial de Ordenes') }}</h1>
@endsection

@section('content')
    <div class="page-content-wrapper">
        <div class="container-fluid">
            <div class="col-12">
                @if (session('status'))
                    <div class="alert alert-success alert-dismissible fade show" role="alert">
                        {{ session('status') }}
                        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                @endif
            </div>
            <div class="row">
                <div class="col-12">
                    <div class="card">
                        <div class="card-body">
                            <table id="datatable" class="table dt-responsive nowrap table-vertical" width="100%" cellspacing="0">
                                <thead>
                                <tr>
                                    <th>{{ __('Orden_id') }}</th>
                                    <th>{{ __('Total') }}</th>
                                    <th>{{ __('Revisión Manual') }}</th>
                                    <th>{{ __('Fecha Creación') }}</th>
                                    <th>{{ __('Fecha Entrega') }}</th>
                                    <th>{{ __('Estado') }}</th>
                                </tr>
                                </thead>
                                <tbody>
                                    @forelse ($ordenes as $ordenesItem)
                                        <tr>
                                            <td>
                                                <a href="{{ route('admin.orden.detalle', $ordenesItem) }}" class="font-600 text-muted">{{ $ordenesItem->num_orden }}</a>
                                            </td>
                                            <td>{{ __('S/. ') }}{{ $ordenesItem->total }}</td>
                                            <td>
                                                @if ($ordenesItem->revision_manual == 1)
                                                    {{ __('Si') }}
                                                @else
                                                    {{ __('No') }}
                                                @endif
                                            </td>
                                            <td>{{ $ordenesItem->fecha_creacion }}</td>
                                            <td>{{ $ordenesItem->fecha_entrega }}</td>
                                            <td>
                                               @if($ordenesItem->status == 'Pendiente' || $ordenesItem->status == 'Dir. Confirmada')
                                                    <span class="badge badge-warning">{{ __('Pendiente') }}</span>
                                                    @if ($ordenesItem->direccion_id)
                                                        <span class="badge badge-info">{{ __('Dir. Confirmada') }}</span>
                                                    @endif
                                                @elseif($ordenesItem->status == 'Entregado')
                                                    <span class="badge badge-success">{{ __('Entregado') }}</span>
                                                @elseif($ordenesItem->status == 'Aceptada')
                                                    <span class="badge badge-info">{{ __('Aceptada') }}</span>
                                                @elseif($ordenesItem->status == 'Verificado')
                                                    <span class="badge badge-success">{{ __('Verificado') }}</span>
                                                @elseif($ordenesItem->status == 'Cancelado')
                                                    <span class="badge badge-danger">{{ __('Cancelado') }}</span>
                                                @elseif($ordenesItem->status == 'Detenida')
                                                    <span class="badge badge-danger">{{ __('Detenida') }}</span>
                                                @elseif($ordenesItem->status == 'Demorado')
                                                    <span class="badge badge-orange">{{ __('Demorado') }}</span>
                                                @elseif($ordenesItem->status == 'Disputa')
                                                    <span class="badge badge-purple">{{ __('Disputa') }}</span>
                                                @elseif($ordenesItem->status == 'Reembolsado')
                                                    <span class="badge badge-dark">{{ __('Reembolsado') }}</span>
                                                @endif
                                            </td>
                                        </tr>
                                    @empty

                                    @endforelse
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div><!-- container -->
    </div> <!-- Page content Wrapper -->

@endsection

@section('script')
<!-- Datatable js -->
<script src="{{ URL::asset('assets/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.js') }}"></script>
<!-- Responsive examples -->
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.responsive.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('script-bottom')
<script type="text/javascript">
    $(document).ready(function () {
        $('#datatable').DataTable({
            "aaSorting": [[ 5, "desc" ]]
        });
    });
</script>

@endsection

