@extends('layouts.master')

@section('css')
<!-- DataTables -->
<link href="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- Responsive datatable examples -->
<link href="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('breadcrumb')
<h3 class="page-title">Todos los Productos</h1>
@endsection

@section('content')
    <div class="page-content-wrapper">
        <div class="container-fluid">
            <div class="col-12">
                @if (session('status'))
                    <div class="alert alert-success alert-dismissible fade show" role="alert">
                        {{ session('status') }}
                        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                @endif
                <a href="{{route('admin.productos.create')}}" type="button" class="btn btn-secondary waves-effect text-white mb-3">
                    {{  __('Crear') }}
                </a>
            </div>
            
            <div class="row">
                <div class="col-12">
                    <div class="card">
                        <div class="card-body">
                            <table class="table table-striped dt-responsive nowrap table-vertical" width="100%" cellspacing="0">
                                <thead>
                                <tr>
                                    <th>{{ __('Imagen') }}</th>
                                    <th>{{ __('Nombre del Producto') }}</th>
                                    <th>{{ __('Marca') }}</th>
                                    <th>{{ __('Precio') }}</th>
                                    <th>{{ __('Unidad') }}</th>
                                    <th>{{ __('Stock') }}</th>
                                    <th>{{ __('Acciones') }}</th>
                                </tr>
                                </thead>
                                <tbody>
                                    @forelse ($producto as $productoItem)
                                        <tr>
                                            <td class="product-list-img">
                                                <img src="{{ Storage::url($productoItem->pr_imagen) }}" class="img-fluid" alt="{{ $productoItem->pr_nombre}}">
                                            </td>
                                            <td>
                                                <h6 class="mt-0 m-b-5">{{ $productoItem->pr_nombre }}</h6>
                                            </td>
                                            <td>{{ $productoItem->pr_marca }}</td>
                                            <td>S/.{{ $productoItem->pr_precio }}</td>
                                            <td>{{ $productoItem->pr_unidad }}</td>
                                            <td>
                                                <div class="progress" style="height: 5px;">
                                                    <div class="progress-bar bg-info" role="progressbar" style="width: 100%;" data-toggle="tooltip" data-placement="top" data-original-title="{{ $productoItem->pr_stock }}" aria-valuenow="{{ $productoItem->pr_stock }}" aria-valuemin="0" aria-valuemax="100"></div>
                                                </div>
                                            </td>
                                            <td>
                                                <form action="{{ route('admin.productos.destroy', $productoItem) }}" method="post">
                                                    @csrf
                                                    @method('delete')
                                                    <a href="{{ route('admin.productos.edit', $productoItem) }}" class="m-r-15 text-muted" data-toggle="tooltip" data-placement="top" title="" data-original-title="Editar"><i class="mdi mdi-pencil font-18"></i></a>
                                                    <button type="button" data-toggle="tooltip" data-placement="top" title="" data-original-title="Eliminar" class="btn btn-danger waves-effect waves-light" onclick="confirm('{{ __("Eliminar Producto?") }}') ? this.parentElement.submit() : ''">
                                                        <i class="mdi mdi-close font-18"></i>
                                                    </button>
                                                </form>
                                                <admin-productos-index :producto="{{ json_encode($productoItem) }}"></admin-productos-index>
                                            </td>
                                        </tr>
                                    @empty

                                    @endforelse
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div><!-- container -->
    </div> <!-- Page content Wrapper -->

@endsection

@section('script')
<!-- Datatable js -->
<script src="{{ URL::asset('assets/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.js') }}"></script>
<!-- Responsive examples -->
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.responsive.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.js') }}"></script>
@endsection

@section('script-bottom')
<script type="text/javascript">
    $(document).ready(function () {
          $('#datatable').DataTable();
    });
</script>

@endsection

