@extends('layouts.master')

@section('css')
<!-- DataTables -->
<link href="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- Responsive datatable examples -->
<link href="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
@endsection

@section('breadcrumb')
<h3 class="page-title">{{ __('Orden: ') }}{{ $orden->num_orden }}</h1>
@endsection

@section('content')
    <div class="page-content-wrapper">
        @include('cliente.ordenes.create-direccion')
        @include('cliente.ordenes.direcciones')
        <div class="container-fluid">
            <div class="row">
                <div class="col-md-8">
                    <div class="card mb-3">
                        <div class="card-body" id="ordenDetalle">
                            <h4 class="mt-0 card-title font-20">
                                <i class="ion-checkmark-round"></i> {{ __('Productos') }}

                                @if($orden->status == 'Pendiente')
                                    <span class="badge badge-warning">{{ __('Pendiente') }}</span>
                                @elseif($orden->status == 'Dir. Confirmada')
                                    <span class="badge badge-info">{{ __('Dirección Confirmada') }}</span>
                                @elseif($orden->status == 'Entregado')
                                    <span class="badge badge-success">{{ __('Entregado') }}</span>
                                @elseif($orden->status == 'Aceptada')
                                    <span class="badge badge-info">{{ __('Aceptada') }}</span>
                                @elseif($orden->status == 'Verificado')
                                    <span class="badge badge-success">{{ __('Verificado') }}</span>
                                @elseif($orden->status == 'Cancelado')
                                    <span class="badge badge-danger">{{ __('Cancelado') }}</span>
                                @elseif($orden->status == 'Detenida')
                                    <span class="badge badge-danger">{{ __('Detenida') }}</span>
                                @elseif($orden->status == 'Demorado')
                                    <span class="badge badge-orange">{{ __('Demorado') }}</span>
                                @elseif($orden->status == 'Disputa')
                                    <span class="badge badge-purple">{{ __('Disputa') }}</span>
                                @elseif($orden->status == 'Reembolsado')
                                    <span class="badge badge-dark">{{ __('Reembolsado') }}</span>
                                @endif
                                
                            </h4>
                            <div class="table-rep-plugin">
                                <div class="table-responsive b-0" data-pattern="priority-columns">
                                    <table id="tech-companies-1" class="table">
                                        <tbody>
                                            @forelse ($detalle as $detalles)
                                                <tr>
                                                    <td>
                                                        <li class="list-inline-item notification-list">
                                                            <a class="nav-link arrow-none waves-effect">
                                                                <img src="{{ Storage::url($detalles->producto->pr_imagen) }}" class="img-fluid" width="100" alt="{{ $detalles->producto->pr_nombre }}">
                                                                <span class="badge badge-blue-grey noti-icon-badge">{{ $detalles->cantidad }}</span>
                                                            </a>
                                                        </li>
                                                    </td>
                                                    <td class="text-left">{{ $detalles->producto->pr_nombre }}</td>
                                                    <td class="text-cemter">S/. {{ $detalles->producto->pr_precio }} {{ __('x') }} {{ $detalles->cantidad }}</td>
                                                    <td class="text-right">S/. {{ $detalles->precio }}</i> </td>
                                                </tr>
                                            @empty
                                                {{ __('No hay información disponible') }}
                                            @endforelse
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <hr/>
                            @if ($orden->status == 'Detenida')
                                <div class="alert alert-warning" role="alert">
                                    <strong>{{ __('Por mayor seguridad.') }}</strong> {{ __('Su orden pasara a ser verificada, por favor espere la respuesta.') }}
                                </div>
                            @elseif($orden->status == 'Entregado')
                                <div class="alert alert-success" role="alert">
                                    <strong>{{ __('Felicidades!') }}</strong> {{ __('Su orden ya fue entregada.') }}
                                </div>
                            @elseif($orden->status == 'Pendiente' || $orden->status == 'Verificado' || $orden->status == 'Dir. Confirmada')
                                <div class="alert alert-info" role="alert">
                                    <strong>{{ __('Gracias por confiar en nosotros.') }}</strong> {{ __('Su orden esta por ser aceptada.') }}
                                </div>
                                @if (!$orden->direccion_id)
                                    <div class="alert alert-warning" role="alert">
                                        <strong>{{ __('Advertencia!') }}</strong> Recuerde agregar su dirección de envio.
                                    </div>
                                @endif
                            @elseif($orden->status == 'Cancelado')
                                <div class="alert alert-danger" role="alert">
                                    <strong>{{ __('Ojo!') }}</strong> {{ __('Su orden ya fue cancelada.') }}
                                </div>
                            @elseif($orden->status == 'Aceptada')
                                <div class="alert alert-info" role="alert">
                                    <strong>{{ __('Genial!') }}</strong> {{ __('Ya estamos preparando su orden, dentro de poco ya lo tendra en sus manos.') }}
                                </div>
                            @elseif($orden->status == 'Demorado')
                                <div class="alert alert-info" role="alert">
                                    <strong>{{ __('Disculpe!') }}</strong> {{ __('Su orden tendra un poco de retraso.') }}
                                </div>
                            @elseif($orden->status == 'Disputa')
                                <div class="alert alert-info" role="alert">
                                    <strong>{{ __('En Proceso!') }}</strong> {{ __('Actualmente la orden se encuentra en disputa, sea paciente y dentro de poco le daremos una respuesta.') }}
                                </div>
                            @elseif($orden->status == 'Reembolsado')
                                <div class="alert alert-info" role="alert">
                                    <strong>{{ __('La Orden fue Reembolsada.') }}</strong> {{ __('Esto acción puede demorar unos cuantos días, para que este en su cuenta nuevamente.') }}
                                </div>
                            @endif
                            <div class="float-right">
                                @if ($orden->status == 'Pendiente' || $orden->status == 'Verificado' || $orden->status == 'Dir. Confirmada')
                                    <a id="{{ $orden->id }}" data-id="{{ $orden->id }}" role="button" data-name="Disputa" class="disputa btn btn-purple waves-effect text-white m-r-15" >{{ __('Abrir Disputa')}}</a>
                                @elseif($orden->status == 'Demorado')
                                    <a id="{{ $orden->id }}" data-id="{{ $orden->id }}" role="button" data-name="Disputa" class="disputa btn btn-purple waves-effect text-white m-r-15" >{{ __('Abrir Disputa')}}</a>
                                @elseif($orden->status == 'Aceptada')
                                    <a id="{{ $orden->id }}" data-id="{{ $orden->id }}" role="button" data-name="Disputa" class="disputa btn btn-purple waves-effect text-white m-r-15" >{{ __('Abrir Disputa')}}</a>
                                    <a id="{{ $orden->id }}" data-id="{{ $orden->id }}" role="button" data-name="Entregado" class="finalizado btn btn-success waves-effect text-white m-r-15" >{{ __('Entregado')}}</a>
                                @endif
                                
                            </div>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h4 class="mt-0 card-title font-20"><i class="ion-checkmark-round"></i>{{ __(' Pagado') }}</h4>
                            <div class="table-rep-plugin">
                                <div class="table-responsive b-0" data-pattern="priority-columns">
                                    <table id="tech-companies-1" class="table">
                                        <tbody>
                                            <tr>
                                                <td>
                                                    <strong>{{ __('SubTotal') }}</strong>
                                                </td>
                                                <td class="text-right"></td>
                                            </tr>
                                            <tr>
                                                <td class="no-line">
                                                    <strong>{{ __('Envio') }}</strong></td>
                                                <td class="no-line text-right"></td>
                                            </tr>
                                            <tr>
                                                <td class="no-line">
                                                    <strong>{{ __('Tax') }}</strong></td>
                                                <td class="no-line text-right"></td>
                                            </tr>
                                            <tr>
                                                <td class="no-line">
                                                    <strong>{{ __('Total') }}</strong></td>
                                                <td class="no-line text-right"><h4 class="m-0">S/ {{ $orden->total }}</h4></td>
                                            </tr>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="card">
                        <div class="card-body">
                            <h6>{{ __('Cliente:') }}</h6>
                            <p>{{ $orden->user_id }} {{ $orden->user->cl_nombre }}</p>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            <h6>{{ __('Información de Contacto: ') }}</h6>
                            <span>{{ $orden->user->email }}</span>
                        </div>
                    </div>
                    <div class="card">
                        <div class="card-body">
                            @if (!$orden->direccion_id)

                            <div class="row text-right">
                                <div class="col-md-12 mb-2">
                                    <a href="" type="button" class="btn btn-outline-dark" data-toggle="modal" data-target="#create-direccion">NUEVO</a>
                                    <a href="" type="button" class="btn btn-outline-success" data-toggle="modal" data-target="#select-direccion">CAMBIAR</a>
                                </div>
                            </div>
                                <span>No cuentas con una dirección de envio, por favor crea o selecciona una de las existentes.</span>
                            @else
                                <h6>{{ __('Dirección de envio: ') }}</h6>
                                <span>{{ $orden->direccion->address }}</span><br/>
                                <span>{{ $orden->direccion->country }}</span><br/>
                                <span>{{ $orden->direccion->departament }}, {{ $orden->direccion->province }}, {{ $orden->direccion->district }}</span><br/>
                                <span>{{ $orden->direccion->cod_postal }}</span><br/>
                                <span>{{ $orden->direccion->reference }}</span>
                            @endif
                        </div>
                    </div>
                </div>
            </div>
        </div><!-- container -->
    </div> <!-- Page content Wrapper -->
@endsection

@section('script')
<!-- Datatable js -->
<script src="{{ URL::asset('assets/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.bootstrap4.min.js') }}"></script>
<!-- Responsive examples -->
<script src="{{ URL::asset('assets/plugins/datatables/dataTables.responsive.min.js') }}"></script>
<script src="{{ URL::asset('assets/plugins/datatables/responsive.bootstrap4.min.js') }}"></script>

@endsection

@section('script-bottom')
<script type="text/javascript">
    $(document).ready(function () {
            $('#datatable').DataTable();
    });
</script>
<script src="{{ URL::asset('js/changeStatus.js') }}"></script>

@endsection