<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::get('/clear-cache', function() {
    $run = Artisan::call('config:clear');
    $run = Artisan::call('cache:clear');
    $run = Artisan::call('config:cache');
    return 'FINISHED';  
});

Route::get('/linkstorage', function () {
    Artisan::call('storage:link');
});

Route::get('qr', 'HomeController@generateQR');

Route::get('/', ['as' => 'home.index', 'uses' => 'HomeController@index']);

Route::get('servicios', ['as' => 'home.servicios', 'uses' => 'HomeController@servicios']);

Route::get('buscador', ['as' => 'home.index', 'uses' => 'HomeController@search']);

Route::get('producto/{pr_slug}', ['as' => 'home.producto', 'uses' => 'HomeController@showProducto']);

Route::get('geolocation', ['as' => 'home.geolocation', 'uses' => 'HomeController@geo']);

Route::get('maps', ['as' => 'home.googlemaps', 'uses' => 'Api\MapsApiController@index']);

Route::get('carrito', ['as' => 'home.carrito', 'uses' => 'HomeController@carrito']);

Route::post('pagar', 'Culqi\OrderController@pagar');
Route::post('orden/crear', 'Culqi\OrderController@createOrden');
Route::post('orden/crear-orden-rapida', 'Culqi\OrderController@createOrdenRapido');

//Paypal
Route::post('payments/pay', 'PaymentController@pay')->name('paypal.pay');
Route::get('payments/approval', 'PaymentController@approval')->name('paypal.approval');
Route::post('payments/order', 'PaymentController@orderCreate');
Route::get('payments/cancelled', 'PaymentController@cancelled')->name('paypal.cancelled');
//End Paypal

Route::get('prueba','ProductoController@show');

Route::get('register/comercio','Comercio\ComercioController@index')->name('comercio.auth.register');
Route::post('register/comercio','Comercio\ComercioController@store')->name('comercio.auth.store');

Route::get('remoto','GrupoItemController@index')->name('remoto.index');

//Rutas de la Nueva Tienda

Route::get('productos', 'Tienda\ProductoController@index')->name('home.productos');
Route::get('productos/records', 'Tienda\ProductoController@records');
Route::get('productos/tables', 'Tienda\ProductoController@tables');

Route::get('producto/record/{id}', 'Tienda\ProductoController@record');

Route::get('ver-carrito', 'Tienda\ProductoController@carrito');
Route::get('carrito/records', 'Tienda\PlataformaPagoController@records');

Route::get('checkout', 'Tienda\CheckoutController@index')->name('home.checkout');
Route::get('checkout/tables', 'Tienda\CheckoutController@tables');


//Rutas de comercio
Route::group(['middleware' => 'auth'], function () {

    Route::group(['middleware' => 'role:comercio'], function () {
        Route::group(['prefix' => 'comercio'], function() {

            Route::get('/', ['as' => 'index', 'uses' => 'AdminController@index']);

            // Rutas de administrar clientes
            Route::get('clientes', ['as' => 'admin.clientes.index', 'uses' => 'ClienteController@index']);
            Route::get('clientes/crear', ['as' => 'admin.clientes.create', 'uses' => 'ClienteController@create']);
            Route::post('clientes', ['as' => 'admin.clientes.store', 'uses' => 'ClienteController@store']);
            
            // Rutas de administrar categorias
            Route::get('categorias', ['as' => 'admin.categorias.index', 'uses' => 'CategoriaController@index']);
            Route::get('categorias/crear', ['as' => 'admin.categorias.create', 'uses' => 'CategoriaController@create']);
            Route::post('categorias', ['as' => 'admin.categorias.store', 'uses' => 'CategoriaController@store']);
            Route::get('categorias/{id}', ['as' => 'admin.categorias.edit', 'uses' => 'CategoriaController@edit']);
            Route::put('categorias/{categoriaEdit}', ['as' => 'admin.categorias.update', 'uses' => 'CategoriaController@update']);
            Route::delete('categorias/{categoria}', ['as' => 'admin.categorias.destroy', 'uses' => 'CategoriaController@destroy']);

            // Rutas Productos
            Route::get('productos', ['as' => 'admin.productos.index', 'uses' => 'ProductoController@index']);
            Route::get('productos/crear', ['as' => 'admin.productos.create', 'uses' => 'ProductoController@create']);
            Route::get('productos/record/{id}', 'ProductoController@record');
            Route::get('productos/tables', 'ProductoController@tables');
            Route::get('productos/item/tables/{producto}', 'ProductoController@item_tables');
            Route::post('productos', ['as' => 'admin.productos.store', 'uses' => 'ProductoController@store']);
            Route::post('productos/stock', 'ProductoController@store_stock');
            Route::get('productos/{id}', ['as' => 'admin.productos.edit', 'uses' => 'ProductoController@edit']);
            Route::put('productos/{productoEdit}', ['as' => 'admin.productos.update', 'uses' => 'ProductoController@update']);
            Route::post('productos/upload', ['as' => 'admin.productos.upload', 'uses' => 'ProductoController@upload']);
            Route::delete('productos/{producto}', ['as' => 'admin.productos.destroy', 'uses' => 'ProductoController@destroy']);
            Route::get('productos/images/{id}/delete', 'ProductoController@image_delete')->name('admin.productos.images.delete');

            // Rutas de administrar Ordenes 
            Route::get('ordenes', ['as' => 'admin.orden.index', 'uses' => 'Culqi\OrderController@index']);
            Route::get('ordenes/detalle/{codigo}', ['as' => 'admin.orden.detalle', 'uses' => 'Culqi\OrderController@viewOrder']);

            // Rutas Ordenes
            Route::get('ordencancelada', 'Culqi\OrderController@ordenCancelada');
            Route::get('ordenentregado', 'Culqi\OrderController@ordenEntregado');
            Route::get('ordenverificado', 'Culqi\OrderController@ordenVerificado');
            Route::get('ordenestado', 'Culqi\OrderController@ordenEstado');

            // Rutas Transacciones
            Route::get('transacciones', ['as' => 'admin.transacciones.index', 'uses' => 'AdminController@transactions']);
            Route::get('transacciones-error', ['as' => 'admin.transacciones.error', 'uses' => 'AdminController@transactionsError']);

            // Rutas de Almacén
            Route::get('almacenes', ['as' => 'admin.almacenes.index', 'uses' => 'AlmacenController@index']);
            Route::get('almacenes/crear', ['as' => 'admin.almacenes.create', 'uses' => 'AlmacenController@create']);
            Route::post('almacenes', ['as' => 'admin.almacenes.store', 'uses' => 'AlmacenController@store']);
            Route::get('almacenes/{id}', ['as' => 'admin.almacenes.edit', 'uses' => 'AlmacenController@edit']);
            Route::put('almacenes/{almacenEdit}', ['as' => 'admin.almacenes.update', 'uses' => 'AlmacenController@update']);
            Route::delete('almacenes/{almacen}', ['as' => 'admin.almacenes.destroy', 'uses' => 'AlmacenController@destroy']);

            // Rutas de Tienda
            Route::get('tienda', ['as' => 'admin.tiendas.index', 'uses' => 'TiendaController@index']);
            Route::get('tienda/crear', ['as' => 'admin.tiendas.create', 'uses' => 'TiendaController@create']);
            Route::post('tienda', ['as' => 'admin.tiendas.store', 'uses' => 'TiendaController@store']);
            Route::get('tienda/{id}', ['as' => 'admin.tiendas.edit', 'uses' => 'TiendaController@edit']);
            Route::put('tienda/{tiendaEdit}', ['as' => 'admin.tiendas.update', 'uses' => 'TiendaController@update']);
            Route::delete('tienda/{tienda}', ['as' => 'admin.tiendas.destroy', 'uses' => 'TiendaController@destroy']);

            // Movimientos
            Route::get('movimientos', ['as' => 'admin.movimientos.index', 'uses' => 'Comercio\MovimientosController@index']);
            Route::get('movimientos/records', 'Comercio\MovimientosController@records');
            Route::get('movimientos/tables', 'Comercio\MovimientosController@tables');
            Route::get('movimientos/view/{id}', 'Comercio\MovimientosController@view')->name('admin.movimientos.view');
            Route::post('movimientos/items', 'Comercio\MovimientosController@items');
            Route::post('movimientos/store', 'Comercio\MovimientosController@store');
            Route::post('movimientos/accept/{id}', 'Comercio\MovimientosController@accept');
            Route::post('movimientos/deny/{id}', 'Comercio\MovimientosController@deny');

            //Configuraciones
            Route::get('configuraciones', ['as' => 'admin.configuraciones.index', 'uses' => 'Comercio\ConfiguracionController@index']);
            Route::get('configuraciones/record', 'Comercio\ConfiguracionController@record');
            Route::get('configuraciones/tables', 'Comercio\ConfiguracionController@tables');
            Route::post('configuraciones', 'Comercio\ConfiguracionController@update');

        });
    });

    // Rutas del administrador - Super Administrador
    Route::group(['middleware' => 'role:admin'], function () {
        Route::group(['prefix' => 'super-admin'], function() {
            Route::get('/', ['as' => 'index', 'uses' => 'AdminController@index']);

        });
    });

    // Rutas del Usuario
    Route::group(['middleware' => 'role:user'], function () {
        Route::group(['prefix' => 'welcome'], function() {
            Route::get('/', ['as' => 'home.index', 'uses' => 'HomeController@index']);
            Route::get('mis-ordenes', ['as' => 'cliente.ordenes.index', 'uses' => 'Cliente\OrdenController@index']);
            Route::get('mis-ordenes/detalle/{codigo}', ['as' => 'cliente.ordenes.detalle', 'uses' => 'Cliente\OrdenController@detalle']);
            Route::post('mis-ordenes/detalle/{codigo}', ['as' => 'cliente.orden.update', 'uses' => 'Cliente\OrdenController@update_direccion']);

            Route::get('disputa', 'Cliente\OrdenController@ordenEstado');
            
            // Rutas de direcciones del usuario
            Route::get('direcciones', ['as' => 'cliente.direcciones.index', 'uses' => 'Cliente\AddressController@index']);
            Route::get('direcciones/crear', ['as' => 'cliente.direcciones.create', 'uses' => 'Cliente\AddressController@create']);
            Route::post('direcciones', ['as' => 'cliente.direcciones.store', 'uses' => 'Cliente\AddressController@store']);
            Route::get('direcciones/{id}', ['as' => 'cliente.direcciones.edit', 'uses' => 'Cliente\AddressController@edit']);
            Route::put('direcciones/{direccionEdit}', ['as' => 'cliente.direcciones.update', 'uses' => 'Cliente\AddressController@update']);
            Route::delete('direcciones/{direccion}', ['as' => 'cliente.direcciones.destroy', 'uses' => 'Cliente\AddressController@destroy']);

        });
    });
});
//Route::get('{any}', 'AdmiriaController@index');
// Cliente Verificación
Route::get('bienvenido/usuario/{token}&{email}', ['as' => 'auth.verification.update', 'uses' => 'Auth\ClienteVerificacionController@showUpdateForm']);
Route::post('bienvenido/usuario', ['as' => 'verification.update', 'uses' => 'Auth\ClienteVerificacionController@update']);

Auth::routes();
Route::get('login/facebook', 'Auth\LoginController@facebook')->name('login.facebook');
Route::get('login/facebook/callback', 'Auth\LoginController@facebookRedirect');

Route::get('login/google', 'Auth\LoginController@google')->name('login.google');
Route::get('login/google/callback', 'Auth\LoginController@googleRedirect');
